.. _commands:

Command Palette
===============

All user actions in JupyterLab are processed through a centralized command
system. These commands are shared and used throughout JupyterLab (menu bar,
context menus, keyboard shortcuts, etc.). The command palette provides a
keyboard-driven way to search for and run JupyterLab commands:

.. image:: images/command_palette.png
   :align: center
   :class: jp-screenshot

.. _access-palette:

The command palette can be accessed from the View menu or using the keyboard shortcut
``Command/Ctrl Shift C``.

The command palette can be displayed in the sidebar by adding ``'modal': false`` to the Settings.
